"use client";

import { useState } from "react";
import { EventItem } from "./EventItem";
import { EventFilter } from "./EventFilter";
import { EventFragment, getSingularEvents } from "@/lib/event";
import {
  toLocalTime,
  formatDate,
  commonDateFormat,
  isTodayOrFuture,
} from "@/lib/date";
import styles from "./eventContainer.module.scss";

type EventContainerMode = "list" | "calendar";

export const EventContainer = ({ events }: { events: EventFragment[] }) => {
  const [mode, setMode] = useState<EventContainerMode>("calendar");

  return (
    <div className={styles.events}>
      <EventFilter />
      <div className={styles.eventWrapper}>
        <div className={styles.displayOptions}>
          <button onClick={() => setMode("list")}>Vis liste</button>
          <button onClick={() => setMode("calendar")}>Vis kalender</button>
        </div>
        {mode === "list" && <EventList events={events} />}
        {mode === "calendar" && <EventCalendar events={events} />}
      </div>
    </div>
  );
};

const EventList = ({ events }: { events: EventFragment[] }) => {
  return (
    <ul className={styles.eventList}>
      {events.map((event) => (
        <EventItem key={event.id} event={event} />
      ))}
    </ul>
  );
};

const EventCalendar = ({ events }: { events: EventFragment[] }) => {
  const singularEvents = getSingularEvents(events).filter((x) =>
    x.occurrence?.start && isTodayOrFuture(x.occurrence.start)
  );

  return (
    <ul className={styles.eventList}>
      {singularEvents.map((event) => (
        <EventItem key={event.id} event={event} />
      ))}
    </ul>
  );
};
