"use client";

import styles from "./eventItem.module.scss";
import Link from "next/link";
import Image from "../general/Image";
import { SingularEvent, EventFragment } from "@/lib/event";
import { toLocalTime, formatDate, commonDateFormat } from "@/lib/date";

export const EventItem = ({
  event,
}: {
  event: SingularEvent | EventFragment;
}) => {
  return (
    <li className={`${styles.eventItem} linkItem`}>
      <div className={styles.image}>
        {event.featuredImage && (
          <Image
            src={event.featuredImage.url}
            alt=""
            width={0}
            height={0}
            sizes="20vw"
          />
        )}
      </div>
      <div className={styles.text}>
        <h1 className={styles.title}>{event.title}</h1>
        {event.occurrence?.start && (
          <p className={styles.details}>
            {formatDate(event.occurrence?.start, commonDateFormat)}
          </p>
        )}
      </div>
      <Link href={`/arrangementer/${event.slug}`} className="hiddenLink">
        Mer om arrangementet {event.title}
      </Link>
    </li>
  );
};
